"""
Identifier:     csst_common/dfs.py
Name:           dfs.py
Description:    DFS wrapper
Author:         Bo Zhang
Created:        2023-07-08
Modified-History:
    2023-07-08, Bo Zhang, implemented DFS
    2023-07-11, Bo Zhang, updated DFS
    2023-12-08, Bo Zhang, tweaks
    2023-12-20, Bo Zhang, do nothing in DFS.__init__()
    2023-12-28, Bo Zhang, add DFS.rec_to_table and DFS.rec_to_dlist
"""
from astropy.table import Table
from csst_dfs_api.common.catalog import CatalogApi
from csst_dfs_api.facility import (
    Level0DataApi,
    Level0PrcApi,
    Level1DataApi,
    Level1PrcApi,
    Level2DataApi,
    Level2TypeApi,
    OtherDataApi,
)


class DFS:
    def __init__(self):
        pass

    # DFS APIs
    @property
    def L0DataApi(self):
        return Level0DataApi()

    @property
    def L0PrcApi(self):
        return Level0PrcApi()

    @property
    def L1DataApi(self):
        return Level1DataApi()

    @property
    def L1PrcApi(self):
        return Level1PrcApi()

    @property
    def L2DataApi(self):
        return Level2DataApi()

    @property
    def L2TypeApi(self):
        return Level2TypeApi()

    @property
    def OtherDataApi(self):
        return OtherDataApi()

    @property
    def CatApi(self):
        return CatalogApi()

    @staticmethod
    def rec_to_table(rec):
        assert rec["code"] == 0, rec
        data = list(zip(*rec["data"]))
        colnames = rec["columns"]
        return Table(data=data, names=colnames)

    @staticmethod
    def rec_to_dlist(rec):
        assert rec["code"] == 0, rec
        colnames = rec["columns"]
        return [dict(zip(colnames, _)) for _ in rec["data"]]
